/*
   core/slot.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2.
*/

#include "core/slot.h"
#include "core/item.h"
#include "core/application.h"

namespace core
{

Slot::Slot()
{
	slot_item = 0;
	slot_flags = 0;
	slot_timestamp = 0;
	slot_last_fired = 0;
	slot_cone = 0;
	slot_type = model::Weapon::Cannon;
}

Slot::~Slot()
{
}

void Slot::set_flag(const Flags flag)
{
	slot_flags = (slot_flags | (unsigned int) flag);
	set_timestamp(game() ? game()->timestamp() : 1);
}

void Slot::unset_flag(const Flags flag)
{
	slot_flags = slot_flags & ~((unsigned int) flag);
	set_timestamp(game() ? game()->timestamp() : 1);
}

void Slot::set_item(Item *item)
{
	slot_item = item;
	set_timestamp(game() ? game()->timestamp() : 1);
}

void Slot::load(const model::Weapon * weapon_tag)
{
	if (weapon_tag) {
		set_type(weapon_tag->type());
		set_cone(weapon_tag->cone());
		set_location(weapon_tag->location());
		set_axis(weapon_tag->axis());
	}
}

} // namespace core
